@@ -44,7 +44,7 @@ struct expansionitem {
 		unsigned param;
 	};
 };
-DECLARRAY(expansionitem, static __unused);
+DECLARRAY(expansionitem, static UNUSED);
 DEFARRAY(expansionitem, static);
 
 struct macro {
@@ -57,9 +57,9 @@ struct macro {
 	struct expansionitemarray expansion;
 	bool inuse;
 };
-DECLARRAY(macro, static __unused);
+DECLARRAY(macro, static UNUSED);
 DEFARRAY(macro, static);
-DECLARRAY(macroarray, static __unused);
+DECLARRAY(macroarray, static UNUSED);
 DEFARRAY(macroarray, static);
 
 static struct macroarrayarray macros;
@@ -855,6 +855,8 @@ expand_got_ws(struct expstate *es, struct place *p, char *buf, size_t len)
 	    case ES_WANTLPAREN:
 		break;
 	    case ES_NOARG:
+		expand_newarg(es, buf, len);
+		es->state = ES_HAVEARG;
 		break;
 	    case ES_HAVEARG:
 		expand_appendarg(es, buf, len);
@@ -958,6 +960,10 @@ expand_got_rparen(struct expstate *es, struct place *p, char *buf, size_t len)
 		break;
 	    case ES_NOARG:
 		assert(es->argparens == 0);
+		if (stringarray_num(&es->args) > 0) {
+			/* we are after a comma; enter an empty argument */
+			expand_newarg(es, buf, 0);
+		}
 		es->state = ES_NORMAL;
 		expand_domacro(es, p);
 		break;
