@@ -134,6 +134,11 @@ commandline_def(const struct place *p, char *str)
 	struct place p2;
 	char *val;
 
+	if (*str == '\0') {
+		warnx("-D: macro name expected");
+		die();
+	}
+
 	val = strchr(str, '=');
 	if (val != NULL) {
 		*val = '\0';
@@ -153,6 +158,10 @@ static
 void
 commandline_undef(const struct place *p, char *str)
 {
+	if (*str == '\0') {
+		warnx("-D: macro name expected");
+		die();
+	}
 	commandline_macro_add(p, str, p, NULL);
 }
 
@@ -343,6 +352,10 @@ static
 void
 commandline_addincpath(struct stringarray *arr, char *s)
 {
+	if (*s == '\0') {
+		warnx("Empty include path");
+		die();
+	}
 	stringarray_add(arr, s, NULL);
 }
 
@@ -391,7 +404,7 @@ loadincludepath(void)
 		dir = stringarray_get(&incpath_quote, i);
 		files_addquotepath(dir, false);
 	}
-	files_addquotepath(".", false);
+	files_addquotepath(NULL, false);
 
 	num = stringarray_num(&incpath_user);
 	for (i=0; i<num; i++) {
@@ -873,10 +886,14 @@ check_arg_option(const char *opt, const struct place *argplace, char *arg)
 
 DEAD static
 void
-usage(void)
+usage(const char *argv0)
 {
-	fprintf(stderr, "Usage: %s [options] [infile [outfile]]\n",
-		getprogname());
+	const char *progname;
+
+	progname = strrchr(argv0, '/');
+	progname = progname == NULL ? argv0 : progname + 1;
+
+	fprintf(stderr, "Usage: %s [options] [infile [outfile]]\n", progname);
 	fprintf(stderr, "Common options:\n");
 	fprintf(stderr, "   -C               Retain comments\n");
 	fprintf(stderr, "   -Dmacro[=def]    Predefine macro\n");
@@ -983,7 +1000,7 @@ main(int argc, char *argv[])
 			i++;
 			continue;
 		}
-		usage();
+		usage(argv[0]);
 	}
 	if (i < argc) {
 		inputfile = argv[i++];
@@ -992,7 +1009,7 @@ main(int argc, char *argv[])
 		outputfile = argv[i++];
 	}
 	if (i < argc) {
-		usage();
+		usage(argv[0]);
 	}
 
 	mode.output_file = outputfile;
